paralelocs_qlikapi — documentação Paralelo CS Qlik API SDK for Python 0.2.5

# paralelocs_qlikapi

- paralelocs_qlikapi package
  - Subpackages
    - paralelocs_qlikapi.api package
      - Submodules
      - paralelocs_qlikapi.api.api module
      - paralelocs_qlikapi.api.auth module
      - Module contents
    - paralelocs_qlikapi.method package
      - Submodules
      - paralelocs_qlikapi.method.app module
      - paralelocs_qlikapi.method.base module
      - paralelocs_qlikapi.method.reloadtask module
      - paralelocs_qlikapi.method.stream module
      - paralelocs_qlikapi.method.tag module
      - paralelocs_qlikapi.method.task module
      - Module contents
  - Submodules
  - paralelocs_qlikapi.cli module
  - Module contents